@@ -51,15 +51,19 @@ def compile(
 def loop_compiler(args_dic):
 	pre_t = None	# 最終更新日時
 	while True:
-		now_t = os.path.getmtime(input_filename)	# 最終更新日時
+		now_t = os.path.getmtime(args_dic["input"])	# 最終更新日時
 		if now_t != pre_t:
 			pre_t = now_t
 			print("compiling...")
-			# RangeCSSのyaml帳票をjsに変換 [range_css_compiler]
-			compile(
-				org_yaml_filename = args_dic["input"],
-				output_js_filename = args_dic["output"],	# None指定の場合は自動的にinputファイルから空気を読んだファイル名になる
-			)
+			try:
+				# RangeCSSのyaml帳票をjsに変換 [range_css_compiler]
+				compile(
+					org_yaml_filename = args_dic["input"],
+					output_js_filename = args_dic["output"],	# None指定の場合は自動的にinputファイルから空気を読んだファイル名になる
+				)
+			except Exception as e:
+				print(repr(e))
+				print("[range-css-compiler error] An error occurred during compilation.")
 			print("waiting...")
 		# 少し休む
 		time.sleep(0.5)
