@@ -57,48 +57,97 @@ function res_x_to_solved_style(res_x_dic, css_id_ls){
 	return rcss_solved_style;
 }
 
+// 左上を(0,0)としたframe_infoを作る
+function make_fi_0(frame_info){
+    frame_info_0 = {...frame_info, posX: 0, posY: 0};
+    return frame_info_0
+}
+
+// frame_infoの一致性確認
+function compare_fi(frame_info_1, frame_info_2) {
+    const keys = ["posX", "posY", "width", "height"];
+    for (let i = 0; i < keys.length; i++) {
+        const key = keys[i];
+        if (frame_info_1[key] != frame_info_2[key]) {return false;}
+    }
+    return true;
+}
+
+// 結果がキャッシュされた配置最適化
+let pre_frame_info = {};
+let so_cache = null;
+function cached_style_opt(frame_info){
+    // frame_infoの一致性確認
+    if (compare_fi(frame_info, pre_frame_info)) {
+        return so_cache;
+    }
+    // 配置の最適化
+    var res_x_dic = opt_core(frame_info);
+    // res_x_dic を solved_styleに変換
+    var rcss_solved_style = res_x_to_solved_style(res_x_dic, css_id_ls);
+    // cacheに保存
+    pre_frame_info = frame_info;
+    so_cache = rcss_solved_style;
+    return rcss_solved_style
+}
+
+// 左上の基準点をずらす
+function shift_pos(rcss_solved_style_0, frame_info){
+    var rcss_solved_style = [];
+    for(one_ele_style of rcss_solved_style_0){
+        rcss_solved_style.push({
+            ...one_ele_style,
+            "posX": one_ele_style["posX"] + frame_info["posX"],
+            "posY": one_ele_style["posY"] + frame_info["posY"],
+        });
+    }
+    return rcss_solved_style;
+}
+
 // 配置最適化計算
 function style_opt(frame_info){
-	// 配置の最適化
-	var res_x_dic = opt_core(frame_info);
-	// res_x_dic を solved_styleに変換
-	var rcss_solved_style = res_x_to_solved_style(res_x_dic, css_id_ls);
-	return rcss_solved_style;
+    // 左上を(0,0)としたframe_infoを作る
+    var frame_info_0 = make_fi_0(frame_info);
+    // 結果がキャッシュされた配置最適化
+    var rcss_solved_style_0 = cached_style_opt(frame_info_0);
+    // 左上の基準点をずらす
+    return shift_pos(rcss_solved_style_0, frame_info);
 }
 
 // frameのオフセット位置・サイズの計算
 function calc_frame_info(){
-	// frameの位置と大きさを表すオブジェクトの取得
-	var e = document.getElementById("rcss_frame");
-	var rect = e.getBoundingClientRect();
-	// frame_infoオブジェクトの形にまとめる
-	var frame_info = {
-		"posX": rect.left,
-		"posY": rect.top,
-		"width": rect.width,
-		"height": rect.height,
-	}
-	return frame_info;
+    // frameの位置と大きさを表すオブジェクトの取得
+    var e = document.getElementById("rcss_frame");
+    var rect = e.getBoundingClientRect();
+    // frame_infoオブジェクトの形にまとめる
+    var frame_info = {
+        "posX": rect.left,
+        "posY": rect.top,
+        "width": rect.width,
+        "height": rect.height,
+    }
+    return frame_info;
 }
 
 // 1つの要素についてstyleを適用
 function apply_style_one_ele(one_ele_style){
-	// 対象要素を見つける
-	var target = document.getElementById(one_ele_style["css_id"]);
-	// cssのスタイル適用
-	target.style.position = "fixed";
-	target.style.left = one_ele_style["posX"];
-	target.style.top = one_ele_style["posY"];
-	target.style.width = one_ele_style["width"];
-	target.style.height = one_ele_style["height"];
+    // 対象要素を見つける
+    var target = document.getElementById(one_ele_style["css_id"]);
+    // cssのスタイル適用
+    target.style.position = "fixed";
+    target.style.left = one_ele_style["posX"];
+    target.style.top = one_ele_style["posY"];
+    target.style.width = one_ele_style["width"];
+    target.style.height = one_ele_style["height"];
 }
 
 // スタイル適用関数
 function apply_rcss_style(rcss_solved_style){
-	for(one_ele_style of rcss_solved_style){
-		// 1つの要素についてstyleを適用
-		apply_style_one_ele(one_ele_style);
-	}
+    for(one_ele_style of rcss_solved_style){
+        if (one_ele_style["css_id"] == "rcss_frame") {continue;}
+        // 1つの要素についてstyleを適用
+        apply_style_one_ele(one_ele_style);
+    }
 }
 """
 
